@@ -11,7 +11,7 @@ class vanityData:
         try: self.ownerId: str = data["ownerId"]
         except (KeyError, TypeError): self.ownerId: str = "Undefined"  
 
-        try: self.disaled: str = data["disaled"]
-        except (KeyError, TypeError): self.disaled: bool = False
+        try: self.disabled: str = data["disabled"]
+        except (KeyError, TypeError): self.disabled: bool = False
 
 # Made by https://wezacon.com - Team Wezacon
\ No newline at end of file
